===================
Kogia documentation
===================

Kogia is a Django toolbox.


----

:Home: https://www.pascalpepe.com/en/
:Documentation: https://pascalpepe.gitlab.io/kogia
:Source code: https://gitlab.com/pascalpepe/kogia
:Issue tracker: https://gitlab.com/pascalpepe/kogia/issues

.. note::

   This project is still in its initial development stage. Anything may change
   at any time.


----

Contents
========

.. toctree::
   :maxdepth: 2

   getting-started
   references/index
   releases/index
   license
